@@ -3,9 +3,9 @@ GUI File Format Converter
 """
 
 # version
-__major__ = 1  # for major interface/format changes
-__minor__ = 7  # for minor interface/format changes
-__release__ = 0  # for tweaks, bug-fixes, or development
+__major__ = 1
+__minor__ = 8
+__release__ = 0
 __prerelease__ = "" # alpha, beta, rc etc.
 
 # package information
