@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2015 Ilias Stamatis <stamatis.iliass@gmail.com>
+# Copyright (C) 2011-2016 Ilias Stamatis <stamatis.iliass@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,12 +15,12 @@
 
 import re
 
-from PyQt4.QtCore import QRegExp, QSize
-from PyQt4.QtGui import (
-        QApplication, QWidget, QComboBox, QLineEdit, QLabel, QRegExpValidator,
-        QPushButton, QCheckBox, QRadioButton, QHBoxLayout, QSpacerItem,
-        QSizePolicy, QFrame, QButtonGroup, QMessageBox, QToolButton,
-        QFileDialog
+from PyQt5.QtGui import QRegExpValidator
+from PyQt5.QtCore import QRegExp, QSize, QTimer
+from PyQt5.QtWidgets import (
+        QApplication, QWidget, QComboBox, QLineEdit, QLabel, QPushButton,
+        QCheckBox, QRadioButton, QHBoxLayout, QSpacerItem, QSizePolicy, QFrame,
+        QButtonGroup, QMessageBox, QToolButton, QFileDialog
         )
 
 from ffmulticonverter import utils
@@ -35,6 +35,7 @@ class AudioVideoTab(QWidget):
         self.name = 'AudioVideo'
 
         self.defaultStr = self.tr('Default')
+        self.DisableStream = self.tr('Disable')
 
         self.formats = config.video_formats
         frequency_values = [self.defaultStr] + config.video_frequency_values
@@ -183,7 +184,7 @@ class AudioVideoTab(QWidget):
         line.setFrameShape(QFrame.HLine)
         line.setFrameShadow(QFrame.Sunken)
         self.moreQPB = QPushButton(QApplication.translate('Tab', 'More'))
-        self.moreQPB.setSizePolicy(QSizePolicy(QSizePolicy.Fixed))
+        self.moreQPB.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
         self.moreQPB.setCheckable(True)
         hlayout3 = utils.add_to_layout('h', line, self.moreQPB)
 
@@ -199,6 +200,8 @@ class AudioVideoTab(QWidget):
         self.defaultQPB.clicked.connect(self.set_default_command)
         self.embedQTB.clicked.connect(self.open_subtitle_file)
         self.moreQPB.toggled.connect(self.frame.setVisible)
+        self.moreQPB.toggled.connect(
+                lambda: QTimer.singleShot(100, self.resize_parent))
         self.widthQLE.textChanged.connect(self.command_update_size)
         self.heightQLE.textChanged.connect(self.command_update_size)
         self.aspect1QLE.textChanged.connect(self.command_update_aspect)
@@ -224,6 +227,11 @@ class AudioVideoTab(QWidget):
         self.preservesizeQChB.toggled.connect(
                 self.command_update_preserve_size)
 
+    def resize_parent(self):
+        """Give MainWindow its default size."""
+        self.parent.setMinimumSize(self.parent.sizeHint())
+        self.parent.resize(self.parent.sizeHint())
+
     def clear(self):
         """Clear all values of graphical widgets."""
         lines = [
@@ -250,18 +258,14 @@ class AudioVideoTab(QWidget):
         # then setExclusive(True) so only one radio button can be set
 
     def fill_video_comboboxes(self, vcodecs, acodecs, extraformats):
-        vcodecs = [i for i in vcodecs.split("\n")] if vcodecs else []
-        acodecs = [i for i in acodecs.split("\n")] if acodecs else []
-        extraformats = [i for i in extraformats.split("\n")] if extraformats else []
-
         self.vidcodecQCB.currentIndexChanged.disconnect()
         self.audcodecQCB.currentIndexChanged.disconnect()
 
         self.vidcodecQCB.clear()
         self.audcodecQCB.clear()
         self.extQCB.clear()
-        self.vidcodecQCB.addItems([self.defaultStr] + vcodecs)
-        self.audcodecQCB.addItems([self.defaultStr] + acodecs)
+        self.vidcodecQCB.addItems([self.defaultStr, self.DisableStream] + vcodecs)
+        self.audcodecQCB.addItems([self.defaultStr, self.DisableStream] + acodecs)
         self.extQCB.addItems(sorted(self.formats + extraformats))
 
         self.vidcodecQCB.currentIndexChanged.connect(self.command_update_vcodec)
@@ -270,26 +274,19 @@ class AudioVideoTab(QWidget):
     def ok_to_continue(self):
         """
         Check if everything is ok with audiovideotab to continue conversion.
-
-        Check if:
-        - Either ffmpeg or avconv are installed.
-
-        Return True if all tests pass, else False.
+        Returns boolean.
         """
-        if self.parent.vidconverter is None:
+        if not self.parent.ffmpeg_path:
             QMessageBox.warning(self, 'FF Multi Converter - ' + self.tr(
-                'Error!'), self.tr('Neither ffmpeg nor libav are installed.'
-                '\nYou will not be able to convert audio/video files until you'
-                ' install one of them.'))
+                'Error!'), self.tr('FFmpeg is not installed!'))
             return False
         return True
 
     def open_subtitle_file(self):
-        """
-        Get the filename using standard QtDialog and update embedQLE's text.
-        """
-        fname = QFileDialog.getOpenFileName(self, 'FF Multi Converter - ' +
-                self.tr('Choose File'), config.home, 'Subtitles (*.srt *.sub)')
+        fname = QFileDialog.getOpenFileName(
+                self, 'FF Multi Converter - ' + self.tr('Choose File'),
+                config.home, 'Subtitles (*.srt *.sub *.ssa *.ass)'
+                )[0]
         if fname:
             self.embedQLE.setText(fname)
 
@@ -525,13 +522,18 @@ class AudioVideoTab(QWidget):
         text = self.vidcodecQCB.currentText()
 
         regex = r'(\s+|^)-(vcodec|c:v)\s+\S+(\s+|$)'
-        if self.vidcodecQCB.currentIndex() != 0:
-            s = ' -vcodec {0} '.format(text)
-        else:
+        regex_vn = r'(\s+|^)-vn(\s+|$)'
+        if self.vidcodecQCB.currentIndex() == 1:
+            s = ' -vn '.format(text)
+        elif self.vidcodecQCB.currentIndex() == 0:
             s = ' '
+        else:
+            s = ' -vcodec {0} '.format(text)
 
         if re.search(regex, command):
             command = re.sub(regex, s, command)
+        elif re.search(regex_vn, command):
+            command = re.sub(regex_vn, s, command)
         else:
             command += s
 
@@ -543,13 +545,18 @@ class AudioVideoTab(QWidget):
         text = self.audcodecQCB.currentText()
 
         regex = r'(\s+|^)-(acodec|c:a)\s+\S+(\s+|$)'
-        if self.audcodecQCB.currentIndex() != 0:
-            s = ' -acodec {0} '.format(text)
-        else:
+        regex_an = r'(\s+|^)-an(\s+|$)'
+        if self.audcodecQCB.currentIndex() == 1:
+            s = ' -an '.format(text)
+        elif self.audcodecQCB.currentIndex() == 0:
             s = ' '
+        else:
+            s = ' -acodec {0} '.format(text)
 
         if re.search(regex, command):
             command = re.sub(regex, s, command)
+        elif re.search(regex_an, command):
+            command = re.sub(regex_an, s, command)
         else:
             command += s
 
