@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2015 Ilias Stamatis <stamatis.iliass@gmail.com>
+# Copyright (C) 2011-2016 Ilias Stamatis <stamatis.iliass@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,14 +20,15 @@ import textwrap
 import logging
 import webbrowser
 
-from PyQt4.QtCore import (
-        PYQT_VERSION_STR, QCoreApplication, QLocale, QSettings,
-        Qt, QTimer, QTranslator, QT_VERSION_STR
+from PyQt5.QtGui import QIcon, QKeySequence
+from PyQt5.QtCore import (
+        PYQT_VERSION_STR, QCoreApplication, QLocale, QSettings, Qt,
+        QTranslator, QT_VERSION_STR
         )
-from PyQt4.QtGui import (
-        QAbstractItemView, QApplication, QCheckBox, QFileDialog, QIcon,
-        QKeySequence, QLabel, QLineEdit, QMainWindow, QMessageBox,
-        QPushButton, QShortcut, QTabWidget, QToolButton, QWidget
+from PyQt5.QtWidgets import (
+        QAbstractItemView, QApplication, QCheckBox, QFileDialog, QLabel,
+        QLineEdit, QMainWindow, QMessageBox, QPushButton, QShortcut, QTabWidget,
+        QToolButton, QWidget
         )
 
 import ffmulticonverter as ffmc
@@ -104,7 +105,7 @@ class MainWindow(QMainWindow):
 
         openAction = utils.create_action(
                 self, self.tr('Open'), QKeySequence.Open, None,
-                self.tr('Open a file'), self.add_files
+                self.tr('Open a file'), self.filesList_add
                 )
         convertAction = utils.create_action(
                 self, self.tr('Convert'), 'Ctrl+C', None,
@@ -190,31 +191,36 @@ class MainWindow(QMainWindow):
                 imagemagickdocAction, None, aboutAction]
                 )
 
-        self.filesList.dropped.connect(self.add_files_dropped)
-        addQPB.clicked.connect(self.add_files)
-        delQPB.clicked.connect(self.delete_files)
-        clearQPB.clicked.connect(self.clear_fileslist)
+        self.filesList.dropped.connect(self.filesList_add_dragged)
+        addQPB.clicked.connect(self.filesList_add)
+        delQPB.clicked.connect(self.filesList_delete)
+        clearQPB.clicked.connect(self.filesList_clear)
         self.tabWidget.currentChanged.connect(
                 lambda: self.tabs[0].moreQPB.setChecked(False))
         self.origQCB.toggled.connect(
                 lambda: self.toQLE.setEnabled(not self.origQCB.isChecked()))
-        self.toQTB.clicked.connect(self.open_dir)
+        self.toQTB.clicked.connect(self.get_output_folder)
         convertQPB.clicked.connect(convertAction.triggered)
 
         del_shortcut = QShortcut(self)
         del_shortcut.setKey(Qt.Key_Delete)
-        del_shortcut.activated.connect(self.delete_files)
+        del_shortcut.activated.connect(self.filesList_delete)
 
         self.setWindowTitle('FF Multi Converter')
 
-        QTimer.singleShot(0, self.check_for_dependencies)
-        QTimer.singleShot(0, self.load_settings)
-        QTimer.singleShot(0, self.audiovideo_tab.set_default_command)
-        QTimer.singleShot(0, self.update_filesList)
+        self.load_settings()
+        self.check_for_dependencies()
+
+        self.audiovideo_tab.set_default_command()
+        self.image_tab.set_default_command()
+        self.toQLE.setText(self.default_output)
+
+        self.filesList_update()
+
 
     def parse_cla(self):
         """Parse command line arguments."""
-        for i in QCoreApplication.argv()[1:]:
+        for i in QCoreApplication.arguments()[1:]:
             i = os.path.abspath(i)
             if os.path.isfile(i):
                 self.fnames.append(i)
@@ -226,17 +232,15 @@ class MainWindow(QMainWindow):
         Check if each one of the program dependencies are installed and
         update self.dependenciesQL with the appropriate message.
         """
-        self.vidconverter = None
-        if utils.is_installed('ffmpeg'):
-            self.vidconverter = 'ffmpeg'
-        elif utils.is_installed('avconv'):
-            self.vidconverter = 'avconv'
+        if not utils.is_installed(self.ffmpeg_path):
+            self.ffmpeg_path = utils.is_installed('ffmpeg')
+            QSettings().setValue('ffmpeg_path', self.ffmpeg_path)
         self.unoconv = utils.is_installed('unoconv')
         self.imagemagick = utils.is_installed('convert')
 
         missing = []
-        if self.vidconverter is None:
-            missing.append('ffmpeg/avconv')
+        if not self.ffmpeg_path:
+            missing.append('ffmpeg')
         if not self.unoconv:
             missing.append('unoconv')
         if not self.imagemagick:
@@ -247,134 +251,88 @@ class MainWindow(QMainWindow):
             status = self.tr('Missing dependencies:') + ' ' + missing
             self.dependenciesQL.setText(status)
 
-    def load_settings(self, onstart=True):
-        """
-        Load settings values.
-
-        onstart -- True means that this is the first time the method called,
-                   usually when program beggins
-        """
-        def get_str_value(settings, name):
-            value = settings.value(name)
-            if value is not None:
-                return value
-            return ''
-
+    def load_settings(self):
         settings = QSettings()
-        self.overwrite_existing = utils.str_to_bool(
-                get_str_value(settings, 'overwrite_existing'))
-        self.default_output = get_str_value(settings, 'default_output')
-        self.prefix = get_str_value(settings, 'prefix')
-        self.suffix = get_str_value(settings, 'suffix')
-        defcmd = get_str_value(settings, 'default_command')
-        extraformats = get_str_value(settings, 'extraformats')
-        videocodecs = settings.value('videocodecs')
-        audiocodecs = settings.value('audiocodecs')
 
-        if videocodecs is None:
-            videocodecs = "\n".join(config.video_codecs)
-            settings.setValue('videocodecs', videocodecs)
-        if audiocodecs is None:
-            audiocodecs = "\n".join(config.audio_codecs)
-            settings.setValue('audiocodecs', audiocodecs)
+        self.overwrite_existing = settings.value('overwrite_existing', type=bool)
+        self.default_output = settings.value('default_output', type=str)
+        self.prefix = settings.value('prefix', type=str)
+        self.suffix = settings.value('suffix', type=str)
+        self.ffmpeg_path = settings.value('ffmpeg_path', type=str)
+        self.default_command = (settings.value('default_command', type=str) or
+                config.default_ffmpeg_cmd)
+        # type=list won't work for some reason
+        extraformats_video = (settings.value('extraformats_video') or [])
+        videocodecs = (settings.value('videocodecs') or config.video_codecs)
+        audiocodecs = (settings.value('audiocodecs') or config.audio_codecs)
+        self.default_command_image = (settings.value('default_command_image',
+                type=str) or
+                config.default_imagemagick_cmd)
+        extraformats_image = (settings.value('extraformats_image') or [])
+        extraformats_document = (settings.value('extraformats_document') or [])
 
-        if defcmd:
-            self.default_command = defcmd
-        else:
-            self.default_command = config.default_ffmpeg_cmd
+        self.audiovideo_tab.fill_video_comboboxes(videocodecs,
+                audiocodecs, extraformats_video)
+        self.image_tab.fill_extension_combobox(extraformats_image)
+        self.document_tab.fill_extension_combobox(extraformats_document)
 
-        self.audiovideo_tab.fill_video_comboboxes(
-                videocodecs, audiocodecs, extraformats)
-
-        if onstart:
-            self.toQLE.setText(self.default_output)
-
-    def current_tab(self):
-        """Return the corresponding object of the selected tab."""
+    def get_current_tab(self):
         for i in self.tabs:
             if self.tabs.index(i) == self.tabWidget.currentIndex():
                 return i
 
-    def update_filesList(self):
-        """Clear self.filesList and add to it all items of self.fname."""
+    def filesList_update(self):
         self.filesList.clear()
         for i in self.fnames:
             self.filesList.addItem(i)
 
-    def add_files(self):
-        """
-        Get file names using a standard Qt dialog.
-        Append to self.fnames each file name that not already exists
-        and update self.filesList.
-        """
-        # Create lists holding file formats extension.
-        # To be passed in QFileDialog.getOpenFileNames().
-        all_files = '*'
-        audiovideo_files = ' '.join(
-                ['*.'+i for i in self.audiovideo_tab.formats])
-        img_formats = self.image_tab.formats[:]
-        img_formats.extend(self.image_tab.extra_img)
-        image_files = ' '.join(['*.'+i for i in img_formats])
-        document_files = ' '.join(['*.'+i for i in self.document_tab.formats])
-        formats = [all_files, audiovideo_files, image_files, document_files]
-        strings = [self.tr('All Files'), self.tr('Audio/Video Files'),
-                   self.tr('Image Files'), self.tr('Document Files')]
-
-        filters = ''
-        for string, extensions in zip(strings, formats):
-            filters += string + ' ({0});;'.format(extensions)
-        filters = filters[:-2] # remove last ';;'
+    def filesList_add(self):
+        filters  = 'All Files (*);;'
+        filters += 'Audio/Video Files (*.{});;'.format(
+                ' *.'.join(self.audiovideo_tab.formats))
+        filters += 'Image Files (*.{});;'.format(
+                ' *.'.join(self.image_tab.formats + self.image_tab.extra_img))
+        filters += 'Document Files (*.{})'.format(
+                ' *.'.join(self.document_tab.formats))
 
         fnames = QFileDialog.getOpenFileNames(self, 'FF Multi Converter - ' +
-                self.tr('Choose File'), config.home, filters)
+                self.tr('Choose File'), config.home, filters,
+                options=QFileDialog.HideNameFilterDetails)[0]
 
         if fnames:
             for i in fnames:
                 if not i in self.fnames:
                     self.fnames.append(i)
-            self.update_filesList()
+            self.filesList_update()
 
-    def add_files_dropped(self, links):
-        """
-        Append to self.fnames each file name that not already exists
-        and update self.filesList.
-        """
+    def filesList_add_dragged(self, links):
         for path in links:
             if os.path.isfile(path) and not path in self.fnames:
                 self.fnames.append(path)
-        self.update_filesList()
+        self.filesList_update()
 
-    def delete_files(self):
-        """
-        Get selectedItems of self.filesList, remove them from self.fnames and
-        update the filesList.
-        """
+    def filesList_delete(self):
         items = self.filesList.selectedItems()
         if items:
             for i in items:
                 self.fnames.remove(i.text())
-            self.update_filesList()
+            self.filesList_update()
 
-    def clear_fileslist(self):
-        """Make self.fnames empty and update self.filesList."""
+    def filesList_clear(self):
         self.fnames = []
-        self.update_filesList()
+        self.filesList_update()
 
     def clear_all(self):
-        """Clear all values of graphical widgets."""
+        """Clears or sets to default the values of all graphical widgets."""
         self.toQLE.clear()
         self.origQCB.setChecked(False)
         self.deleteQCB.setChecked(False)
-        self.clear_fileslist()
+        self.filesList_clear()
 
         self.audiovideo_tab.clear()
         self.image_tab.clear()
 
-    def open_dir(self):
-        """
-        Get a directory name using a standard QtDialog and update
-        self.toQLE with dir's name.
-        """
+    def get_output_folder(self):
         if self.toQLE.isEnabled():
             output = QFileDialog.getExistingDirectory(
                     self, 'FF Multi Converter - ' +
@@ -419,7 +377,7 @@ class MainWindow(QMainWindow):
             elif (not self.origQCB.isChecked() and
                   not os.path.exists(self.toQLE.text())):
                 raise ValidationError(self.tr('Output folder does not exists!'))
-            if not self.current_tab().ok_to_continue():
+            if not self.get_current_tab().ok_to_continue():
                 return False
             return True
 
@@ -428,18 +386,6 @@ class MainWindow(QMainWindow):
                     self, 'FF Multi Converter - ' + self.tr('Error!'), str(e))
             return False
 
-    def get_output_extension(self):
-        """Extract the desired output file extension from GUI and return it."""
-        tab = self.current_tab()
-        if tab.name == 'AudioVideo':
-            ext_to = self.audiovideo_tab.extQCB.currentText()
-        elif tab.name == 'Images':
-            ext_to = tab.extQCB.currentText()
-        else:
-            ext_to = tab.convertQCB.currentText().split()[-1]
-
-        return '.' + ext_to
-
     def start_conversion(self):
         """
         Extract the appropriate information from GUI and call the
@@ -448,12 +394,13 @@ class MainWindow(QMainWindow):
         if not self.ok_to_continue():
             return
 
-        tab = self.current_tab()
+        tab = self.get_current_tab()
+        ext_to = '.' + tab.extQCB.currentText()
+
         if tab.name == 'Documents' and not self.office_listener_started:
             utils.start_office_listener()
             self.office_listener_started = True
 
-        ext_to = self.get_output_extension()
         _list = utils.create_paths_list(
                 self.fnames, ext_to, self.prefix, self.suffix,
                 self.toQLE.text(), self.origQCB.isChecked(),
@@ -468,7 +415,7 @@ class MainWindow(QMainWindow):
         """Open the preferences dialog."""
         dialog = preferences_dlg.Preferences(self)
         if dialog.exec_():
-            self.load_settings(onstart=False)
+            self.load_settings()
 
     def open_dialog_presets(self):
         """Open the presets dialog."""
@@ -482,7 +429,7 @@ class MainWindow(QMainWindow):
         text = '''<b> FF Multi Converter {0} </b>
                  <p>{1}
                  <p><a href="{2}">FF Multi Converter - Home Page</a>
-                 <p>Copyright &copy; 2011-2015 {3}
+                 <p>Copyright &copy; 2011-2016 {3}
                  <br>License: {4}
                  <p>Python {5} - Qt {6} - PyQt {7} on {8}'''\
                  .format(ffmc.__version__, msg, ffmc.__url__, ffmc.__author__,
@@ -504,7 +451,7 @@ def main():
     app = QApplication([i.encode('utf-8') for i in sys.argv])
     app.setOrganizationName(ffmc.__name__)
     app.setOrganizationDomain(ffmc.__url__)
-    app.setApplicationName('FF Muli Converter')
+    app.setApplicationName('FF Multi Converter')
     app.setWindowIcon(QIcon(':/ffmulticonverter.png'))
 
     locale = QLocale.system().name()
