@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2015 Ilias Stamatis <stamatis.iliass@gmail.com>
+# Copyright (C) 2011-2016 Ilias Stamatis <stamatis.iliass@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@ import re
 import time
 import xml.etree.ElementTree as etree
 
-from PyQt4.QtCore import Qt, QTimer
-from PyQt4.QtGui import (
+from PyQt5.QtCore import Qt, QTimer
+from PyQt5.QtWidgets import (
         QDialog, QDialogButtonBox, QFileDialog, QLabel, QLineEdit, QListWidget,
         QMessageBox, QPushButton, QShortcut, QSizePolicy, QSpacerItem
         )
@@ -99,21 +99,13 @@ class ShowPresets(QDialog):
 
     def load_xml(self):
         """Load xml tree and set xml root."""
-        try:
+        if os.path.isfile(self.current_presets_file):
             self.tree = etree.parse(self.current_presets_file)
-        except (etree.ParseError, FileNotFoundError):
-            try:
-                self.tree = etree.parse(self.original_presets_file)
-            except FileNotFoundError:
-                # when program is not installed
-                try:
-                    self.tree = etree.parse('share/' + config.presets_file_name)
-                except FileNotFoundError:
-                    # when running from test_dialogs.py
-                    self.tree = etree.parse(
-                            '../share/' + config.presets_file_name)
+        else:
+            self.tree = etree.parse(self.original_presets_file)
             if not os.path.exists(config.config_dir):
                 os.makedirs(config.config_dir)
+
         self.root = self.tree.getroot()
 
     def set_buttons_clear_lineEdits(self):
@@ -258,7 +250,7 @@ class ShowPresets(QDialog):
                 'presets will be deleted.\nAre you sure that you want to '
                 'continue?'), QMessageBox.Yes|QMessageBox.Cancel)
         if reply == QMessageBox.Yes:
-            fname = QFileDialog.getOpenFileName(self, title)
+            fname = QFileDialog.getOpenFileName(self, title, config.home)[0]
             if fname:
                 msg = self.tr('Successful import!')
                 try:
@@ -274,7 +266,8 @@ class ShowPresets(QDialog):
         """Export the xml tree."""
         fname = QFileDialog.getSaveFileName(
                 self, 'FF Multi Converter - ' + self.tr('Export presets'),
-                config.home + '/presets-' + time.strftime("%Y-%m-%d") + '.xml')
+                config.home + '/presets-' + time.strftime("%Y-%m-%d") + '.xml'
+                )[0]
         if fname:
             self.load_xml()
             with open(fname, 'wb') as _file:
